#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

  GtkWidget *window;
  GtkWidget *notebook;

GtkWidget*
create_window (void)
{

  GtkWidget *alignment1;
  GtkWidget *alignment2;
  GtkWidget *alignment3;
  GtkWidget *alignment4;
  GtkWidget *alignment5;
  GtkWidget *alignment6;
  GtkWidget *alignment7;
  GtkWidget *alignment8;
  GtkWidget *alignment9;
  GtkWidget *alignment10;
  GtkWidget *alignment11;
  GtkWidget *alignment12;
  GtkWidget *alignment13;
  GtkWidget *alignment14;
  GtkWidget *hbox1;
  GtkWidget *hbox2;
  GtkWidget *hbox3;
  GtkWidget *hbox4;
  GtkWidget *hbox5;
  GtkWidget *hbox6;
  GtkWidget *hbox7;
  GtkWidget *hbox8;
  GtkWidget *hbox9;
  GtkWidget *hbox10;
  GtkWidget *hbox11;
  GtkWidget *hbox12;
  GtkWidget *hbox13;
  GtkWidget *hbox14;
  GtkWidget *hbox15;
  GtkWidget *hbox16;
  GtkWidget *hbox17;
  GtkWidget *hbox18;
  GtkWidget *hbox19;
  GtkWidget *hbox20;
  GtkWidget *hbox21;
  GtkWidget *hbox22;
  GtkWidget *hbox23;
  GtkWidget *hbox24;
  GtkWidget *hbox25;
  GtkWidget *hbox26;
  GtkWidget *hbox27;
  GtkWidget *hbox28;
  GtkWidget *hbuttonbox1;
  GtkWidget *hbuttonbox2;
  GtkWidget *hbuttonbox3;
  GtkWidget *hbuttonbox4;
  GtkWidget *hbuttonbox5;
  GtkWidget *hbuttonbox6;
  GtkWidget *hbuttonbox7;
  GtkWidget *hbuttonbox8;
  GtkWidget *hbuttonbox9;
  GtkWidget *hbuttonbox10;
  GtkWidget *hbuttonbox11;
  GtkWidget *hbuttonbox12;
  GtkWidget *hbuttonbox13;
  GtkWidget *hbuttonbox14;
  GtkWidget *image1;
  GtkWidget *image2;
  GtkWidget *image3;
  GtkWidget *image4;
  GtkWidget *image5;
  GtkWidget *image6;
  GtkWidget *image7;
  GtkWidget *image8;
  GtkWidget *image9;
  GtkWidget *image10;
  GtkWidget *image11;
  GtkWidget *image12;
  GtkWidget *image13;
  GtkWidget *image14;
  GtkWidget *image15;
  GtkWidget *image16;
  GtkWidget *image17;
  GtkWidget *image18;
  GtkWidget *image19;
  GtkWidget *image20;
  GtkWidget *image21;
  GtkWidget *image22;
  GtkWidget *image23;
  GtkWidget *image24;
  GtkWidget *image25;
  GtkWidget *image26;
  GtkWidget *image27;
  GtkWidget *image28;
  GtkWidget *label1;
  GtkWidget *label2;
  GtkWidget *label3;
  GtkWidget *label4;
  GtkWidget *label5;
  GtkWidget *label6;
  GtkWidget *label7;
  GtkWidget *label8;
  GtkWidget *label9;
  GtkWidget *label10;
  GtkWidget *label11;
  GtkWidget *label12;
  GtkWidget *label13;
  GtkWidget *label14;
  GtkWidget *label15;
  GtkWidget *label16;
  GtkWidget *label17;
  GtkWidget *label18;
  GtkWidget *label19;
  GtkWidget *label20;
  GtkWidget *label21;
  GtkWidget *label22;
  GtkWidget *label23;
  GtkWidget *label24;
  GtkWidget *label25;
  GtkWidget *label26;
  GtkWidget *label27;
  GtkWidget *label28;
  GtkWidget *label29;
  GtkWidget *label30;
  GtkWidget *label31;
  GtkWidget *label32;
  GtkWidget *label33;
  GtkWidget *label34;
  GtkWidget *label35;
  GtkWidget *label36;
  GtkWidget *label37;
  GtkWidget *label38;
  GtkWidget *label39;
  GtkWidget *label40;
  GtkWidget *label41;
  GtkWidget *label42;
  GtkWidget *label43;
  GtkWidget *label44;
  GtkWidget *label45;
  GtkWidget *label46;
  GtkWidget *label47;
  GtkWidget *label48;
  GtkWidget *label49;
  GtkWidget *label50;
  GtkWidget *label51;
  GtkWidget *label52;
  GtkWidget *label53;
  GtkWidget *label54;
  GtkWidget *label55;
  GtkWidget *label56;
  GtkWidget *page0_cancel_button;
  GtkWidget *page0_install_button;
  GtkWidget *page1_cancel_button;
  GtkWidget *page1_install_button;
  GtkWidget *page2_cancel_button;
  GtkWidget *page2_install_button;
  GtkWidget *page3_cancel_button;
  GtkWidget *page3_install_button;
  GtkWidget *page4_cancel_button;
  GtkWidget *page4_install_button;
  GtkWidget *page5_cancel_button;
  GtkWidget *page5_install_button;
  GtkWidget *page6_cancel_button;
  GtkWidget *page6_install_button;
  GtkWidget *page7_cancel_button;
  GtkWidget *page7_install_button;
  GtkWidget *page8_cancel_button;
  GtkWidget *page8_install_button;
  GtkWidget *page9_cancel_button;
  GtkWidget *page9_install_button;
  GtkWidget *page10_cancel_button;
  GtkWidget *page10_install_button;
  GtkWidget *page11_cancel_button;
  GtkWidget *page11_install_button;
  GtkWidget *page12_cancel_button;
  GtkWidget *page12_install_button;
  GtkWidget *page13_cancel_button;
  GtkWidget *page13_install_button;
  GtkWidget *vbox1;
  GtkWidget *vbox2;
  GtkWidget *vbox3;
  GtkWidget *vbox4;
  GtkWidget *vbox5;
  GtkWidget *vbox6;
  GtkWidget *vbox7;
  GtkWidget *vbox8;
  GtkWidget *vbox9;
  GtkWidget *vbox10;
  GtkWidget *vbox11;
  GtkWidget *vbox12;
  GtkWidget *vbox13;
  GtkWidget *vbox14;

  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (window), _("No application installed"));
  gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER_ALWAYS);
  gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
  gtk_window_set_icon_name (GTK_WINDOW (window), "gtk-dialog-warning");

  notebook = gtk_notebook_new ();
  gtk_widget_show (notebook);
  gtk_container_add (GTK_CONTAINER (window), notebook);
  gtk_container_set_border_width (GTK_CONTAINER (notebook), 10);
  GTK_WIDGET_UNSET_FLAGS (notebook, GTK_CAN_FOCUS);
  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (notebook), vbox1);

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);

  image1 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image1);
  gtk_box_pack_start (GTK_BOX (hbox1), image1, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image1), 10, 0);

  label4 = gtk_label_new (_("<b><span size=\"large\">No application installed for ZIP\ncompressed files</span></b>"));
  gtk_widget_show (label4);
  gtk_box_pack_start (GTK_BOX (hbox1), label4, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label4), TRUE);

  label5 = gtk_label_new (_("You are trying to open a zip file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label5);
  gtk_box_pack_start (GTK_BOX (vbox1), label5, FALSE, FALSE, 10);

  hbuttonbox1 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox1);
  gtk_box_pack_end (GTK_BOX (vbox1), hbuttonbox1, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox1), 10);

  page0_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page0_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox1), page0_cancel_button);
  GTK_WIDGET_SET_FLAGS (page0_cancel_button, GTK_CAN_DEFAULT);

  page0_install_button = gtk_button_new ();
  gtk_widget_show (page0_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox1), page0_install_button);
  GTK_WIDGET_SET_FLAGS (page0_install_button, GTK_CAN_DEFAULT);

  alignment1 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment1);
  gtk_container_add (GTK_CONTAINER (page0_install_button), alignment1);

  hbox2 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox2);
  gtk_container_add (GTK_CONTAINER (alignment1), hbox2);

  image2 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image2);
  gtk_box_pack_start (GTK_BOX (hbox2), image2, FALSE, FALSE, 0);

  label6 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label6);
  gtk_box_pack_start (GTK_BOX (hbox2), label6, FALSE, FALSE, 0);

  label1 = gtk_label_new (_("label1"));
  gtk_widget_show (label1);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 0), label1);

  vbox2 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox2);
  gtk_container_add (GTK_CONTAINER (notebook), vbox2);

  hbox3 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox3);
  gtk_box_pack_start (GTK_BOX (vbox2), hbox3, FALSE, FALSE, 0);

  image3 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image3);
  gtk_box_pack_start (GTK_BOX (hbox3), image3, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image3), 10, 0);

  label7 = gtk_label_new (_("<b><span size=\"large\">No application installed for RAR\ncompressed files</span></b>"));
  gtk_widget_show (label7);
  gtk_box_pack_start (GTK_BOX (hbox3), label7, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label7), TRUE);

  label8 = gtk_label_new (_("You are trying to open a rar file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label8);
  gtk_box_pack_start (GTK_BOX (vbox2), label8, FALSE, FALSE, 10);

  hbuttonbox2 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox2);
  gtk_box_pack_end (GTK_BOX (vbox2), hbuttonbox2, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox2), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox2), 10);

  page1_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page1_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox2), page1_cancel_button);
  GTK_WIDGET_SET_FLAGS (page1_cancel_button, GTK_CAN_DEFAULT);

  page1_install_button = gtk_button_new ();
  gtk_widget_show (page1_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox2), page1_install_button);
  GTK_WIDGET_SET_FLAGS (page1_install_button, GTK_CAN_DEFAULT);

  alignment2 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment2);
  gtk_container_add (GTK_CONTAINER (page1_install_button), alignment2);

  hbox4 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox4);
  gtk_container_add (GTK_CONTAINER (alignment2), hbox4);

  image4 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image4);
  gtk_box_pack_start (GTK_BOX (hbox4), image4, FALSE, FALSE, 0);

  label9 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label9);
  gtk_box_pack_start (GTK_BOX (hbox4), label9, FALSE, FALSE, 0);

  label2 = gtk_label_new (_("label2"));
  gtk_widget_show (label2);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 1), label2);

  vbox3 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox3);
  gtk_container_add (GTK_CONTAINER (notebook), vbox3);

  hbox5 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox5);
  gtk_box_pack_start (GTK_BOX (vbox3), hbox5, FALSE, FALSE, 0);

  image5 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image5);
  gtk_box_pack_start (GTK_BOX (hbox5), image5, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image5), 10, 0);

  label10 = gtk_label_new (_("<b><span size=\"large\">No application installed for WMA\nWindows Media Audio files</span></b>"));
  gtk_widget_show (label10);
  gtk_box_pack_start (GTK_BOX (hbox5), label10, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label10), TRUE);

  label11 = gtk_label_new (_("You are trying to open a wma file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label11);
  gtk_box_pack_start (GTK_BOX (vbox3), label11, FALSE, FALSE, 10);

  hbuttonbox3 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox3);
  gtk_box_pack_end (GTK_BOX (vbox3), hbuttonbox3, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox3), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox3), 10);

  page2_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page2_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox3), page2_cancel_button);
  GTK_WIDGET_SET_FLAGS (page2_cancel_button, GTK_CAN_DEFAULT);

  page2_install_button = gtk_button_new ();
  gtk_widget_show (page2_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox3), page2_install_button);
  GTK_WIDGET_SET_FLAGS (page2_install_button, GTK_CAN_DEFAULT);

  alignment3 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment3);
  gtk_container_add (GTK_CONTAINER (page2_install_button), alignment3);

  hbox6 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox6);
  gtk_container_add (GTK_CONTAINER (alignment3), hbox6);

  image6 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image6);
  gtk_box_pack_start (GTK_BOX (hbox6), image6, FALSE, FALSE, 0);

  label12 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label12);
  gtk_box_pack_start (GTK_BOX (hbox6), label12, FALSE, FALSE, 0);

  label3 = gtk_label_new (_("label3"));
  gtk_widget_show (label3);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 2), label3);

  vbox4 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox4);
  gtk_container_add (GTK_CONTAINER (notebook), vbox4);

  hbox7 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox7);
  gtk_box_pack_start (GTK_BOX (vbox4), hbox7, FALSE, FALSE, 0);

  image7 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image7);
  gtk_box_pack_start (GTK_BOX (hbox7), image7, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image7), 10, 0);

  label16 = gtk_label_new (_("<b><span size=\"large\">No application installed for ARJ\ncompressed files</span></b>"));
  gtk_widget_show (label16);
  gtk_box_pack_start (GTK_BOX (hbox7), label16, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label16), TRUE);

  label17 = gtk_label_new (_("You are trying to open an arj file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label17);
  gtk_box_pack_start (GTK_BOX (vbox4), label17, FALSE, FALSE, 10);

  hbuttonbox4 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox4);
  gtk_box_pack_end (GTK_BOX (vbox4), hbuttonbox4, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox4), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox4), 10);

  page3_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page3_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox4), page3_cancel_button);
  GTK_WIDGET_SET_FLAGS (page3_cancel_button, GTK_CAN_DEFAULT);

  page3_install_button = gtk_button_new ();
  gtk_widget_show (page3_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox4), page3_install_button);
  GTK_WIDGET_SET_FLAGS (page3_install_button, GTK_CAN_DEFAULT);

  alignment4 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment4);
  gtk_container_add (GTK_CONTAINER (page3_install_button), alignment4);

  hbox8 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox8);
  gtk_container_add (GTK_CONTAINER (alignment4), hbox8);

  image8 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image8);
  gtk_box_pack_start (GTK_BOX (hbox8), image8, FALSE, FALSE, 0);

  label18 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label18);
  gtk_box_pack_start (GTK_BOX (hbox8), label18, FALSE, FALSE, 0);

  label13 = gtk_label_new (_("label13"));
  gtk_widget_show (label13);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 3), label13);

  vbox5 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox5);
  gtk_container_add (GTK_CONTAINER (notebook), vbox5);

  hbox9 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox9);
  gtk_box_pack_start (GTK_BOX (vbox5), hbox9, FALSE, FALSE, 0);

  image9 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image9);
  gtk_box_pack_start (GTK_BOX (hbox9), image9, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image9), 10, 0);

  label19 = gtk_label_new (_("<b><span size=\"large\">No application installed for M4A\nMpeg-4 Audio files</span></b>"));
  gtk_widget_show (label19);
  gtk_box_pack_start (GTK_BOX (hbox9), label19, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label19), TRUE);

  label20 = gtk_label_new (_("You are trying to open a m4a file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label20);
  gtk_box_pack_start (GTK_BOX (vbox5), label20, FALSE, FALSE, 10);

  hbuttonbox5 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox5);
  gtk_box_pack_end (GTK_BOX (vbox5), hbuttonbox5, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox5), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox5), 10);

  page4_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page4_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox5), page4_cancel_button);
  GTK_WIDGET_SET_FLAGS (page4_cancel_button, GTK_CAN_DEFAULT);

  page4_install_button = gtk_button_new ();
  gtk_widget_show (page4_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox5), page4_install_button);
  GTK_WIDGET_SET_FLAGS (page4_install_button, GTK_CAN_DEFAULT);

  alignment5 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment5);
  gtk_container_add (GTK_CONTAINER (page4_install_button), alignment5);

  hbox10 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox10);
  gtk_container_add (GTK_CONTAINER (alignment5), hbox10);

  image10 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image10);
  gtk_box_pack_start (GTK_BOX (hbox10), image10, FALSE, FALSE, 0);

  label21 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label21);
  gtk_box_pack_start (GTK_BOX (hbox10), label21, FALSE, FALSE, 0);

  label14 = gtk_label_new (_("label14"));
  gtk_widget_show (label14);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 4), label14);

  vbox6 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox6);
  gtk_container_add (GTK_CONTAINER (notebook), vbox6);

  hbox11 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox11);
  gtk_box_pack_start (GTK_BOX (vbox6), hbox11, FALSE, FALSE, 0);

  image11 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image11);
  gtk_box_pack_start (GTK_BOX (hbox11), image11, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image11), 10, 0);

  label22 = gtk_label_new (_("<b><span size=\"large\">No application installed for ACE\ncompressed files</span></b>"));
  gtk_widget_show (label22);
  gtk_box_pack_start (GTK_BOX (hbox11), label22, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label22), TRUE);

  label23 = gtk_label_new (_("You are trying to open an ace file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label23);
  gtk_box_pack_start (GTK_BOX (vbox6), label23, FALSE, FALSE, 10);

  hbuttonbox6 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox6);
  gtk_box_pack_end (GTK_BOX (vbox6), hbuttonbox6, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox6), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox6), 10);

  page5_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page5_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox6), page5_cancel_button);
  GTK_WIDGET_SET_FLAGS (page5_cancel_button, GTK_CAN_DEFAULT);

  page5_install_button = gtk_button_new ();
  gtk_widget_show (page5_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox6), page5_install_button);
  GTK_WIDGET_SET_FLAGS (page5_install_button, GTK_CAN_DEFAULT);

  alignment6 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment6);
  gtk_container_add (GTK_CONTAINER (page5_install_button), alignment6);

  hbox12 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox12);
  gtk_container_add (GTK_CONTAINER (alignment6), hbox12);

  image12 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image12);
  gtk_box_pack_start (GTK_BOX (hbox12), image12, FALSE, FALSE, 0);

  label24 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label24);
  gtk_box_pack_start (GTK_BOX (hbox12), label24, FALSE, FALSE, 0);

  label15 = gtk_label_new (_("label15"));
  gtk_widget_show (label15);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 5), label15);

  vbox7 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox7);
  gtk_container_add (GTK_CONTAINER (notebook), vbox7);

  hbox13 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox13);
  gtk_box_pack_start (GTK_BOX (vbox7), hbox13, FALSE, FALSE, 0);

  image13 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image13);
  gtk_box_pack_start (GTK_BOX (hbox13), image13, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image13), 10, 0);

  label29 = gtk_label_new (_("<b><span size=\"large\">No application installed for MOV\nQuicktime Movie files</span></b>"));
  gtk_widget_show (label29);
  gtk_box_pack_start (GTK_BOX (hbox13), label29, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label29), TRUE);

  label30 = gtk_label_new (_("You are trying to open a mov file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label30);
  gtk_box_pack_start (GTK_BOX (vbox7), label30, FALSE, FALSE, 10);

  hbuttonbox7 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox7);
  gtk_box_pack_end (GTK_BOX (vbox7), hbuttonbox7, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox7), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox7), 10);

  page6_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page6_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox7), page6_cancel_button);
  GTK_WIDGET_SET_FLAGS (page6_cancel_button, GTK_CAN_DEFAULT);

  page6_install_button = gtk_button_new ();
  gtk_widget_show (page6_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox7), page6_install_button);
  GTK_WIDGET_SET_FLAGS (page6_install_button, GTK_CAN_DEFAULT);

  alignment7 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment7);
  gtk_container_add (GTK_CONTAINER (page6_install_button), alignment7);

  hbox14 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox14);
  gtk_container_add (GTK_CONTAINER (alignment7), hbox14);

  image14 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image14);
  gtk_box_pack_start (GTK_BOX (hbox14), image14, FALSE, FALSE, 0);

  label31 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label31);
  gtk_box_pack_start (GTK_BOX (hbox14), label31, FALSE, FALSE, 0);

  label25 = gtk_label_new (_("label25"));
  gtk_widget_show (label25);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 6), label25);

  vbox8 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox8);
  gtk_container_add (GTK_CONTAINER (notebook), vbox8);

  hbox15 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox15);
  gtk_box_pack_start (GTK_BOX (vbox8), hbox15, FALSE, FALSE, 0);

  image15 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image15);
  gtk_box_pack_start (GTK_BOX (hbox15), image15, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image15), 10, 0);

  label32 = gtk_label_new (_("<b><span size=\"large\">No application installed for MPG\nMpeg Video files</span></b>"));
  gtk_widget_show (label32);
  gtk_box_pack_start (GTK_BOX (hbox15), label32, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label32), TRUE);

  label33 = gtk_label_new (_("You are trying to open a mpg file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label33);
  gtk_box_pack_start (GTK_BOX (vbox8), label33, FALSE, FALSE, 10);

  hbuttonbox8 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox8);
  gtk_box_pack_end (GTK_BOX (vbox8), hbuttonbox8, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox8), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox8), 10);

  page7_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page7_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox8), page7_cancel_button);
  GTK_WIDGET_SET_FLAGS (page7_cancel_button, GTK_CAN_DEFAULT);

  page7_install_button = gtk_button_new ();
  gtk_widget_show (page7_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox8), page7_install_button);
  GTK_WIDGET_SET_FLAGS (page7_install_button, GTK_CAN_DEFAULT);

  alignment8 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment8);
  gtk_container_add (GTK_CONTAINER (page7_install_button), alignment8);

  hbox16 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox16);
  gtk_container_add (GTK_CONTAINER (alignment8), hbox16);

  image16 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image16);
  gtk_box_pack_start (GTK_BOX (hbox16), image16, FALSE, FALSE, 0);

  label34 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label34);
  gtk_box_pack_start (GTK_BOX (hbox16), label34, FALSE, FALSE, 0);

  label26 = gtk_label_new (_("label26"));
  gtk_widget_show (label26);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 7), label26);

  vbox9 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox9);
  gtk_container_add (GTK_CONTAINER (notebook), vbox9);

  hbox17 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox17);
  gtk_box_pack_start (GTK_BOX (vbox9), hbox17, FALSE, FALSE, 0);

  image17 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image17);
  gtk_box_pack_start (GTK_BOX (hbox17), image17, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image17), 10, 0);

  label35 = gtk_label_new (_("<b><span size=\"large\">No application installed for AAC\niTunes Audio files</span></b>"));
  gtk_widget_show (label35);
  gtk_box_pack_start (GTK_BOX (hbox17), label35, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label35), TRUE);

  label36 = gtk_label_new (_("You are trying to open an aac file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label36);
  gtk_box_pack_start (GTK_BOX (vbox9), label36, FALSE, FALSE, 10);

  hbuttonbox9 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox9);
  gtk_box_pack_end (GTK_BOX (vbox9), hbuttonbox9, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox9), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox9), 10);

  page8_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page8_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox9), page8_cancel_button);
  GTK_WIDGET_SET_FLAGS (page8_cancel_button, GTK_CAN_DEFAULT);

  page8_install_button = gtk_button_new ();
  gtk_widget_show (page8_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox9), page8_install_button);
  GTK_WIDGET_SET_FLAGS (page8_install_button, GTK_CAN_DEFAULT);

  alignment9 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment9);
  gtk_container_add (GTK_CONTAINER (page8_install_button), alignment9);

  hbox18 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox18);
  gtk_container_add (GTK_CONTAINER (alignment9), hbox18);

  image18 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image18);
  gtk_box_pack_start (GTK_BOX (hbox18), image18, FALSE, FALSE, 0);

  label37 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label37);
  gtk_box_pack_start (GTK_BOX (hbox18), label37, FALSE, FALSE, 0);

  label27 = gtk_label_new (_("label27"));
  gtk_widget_show (label27);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 8), label27);

  vbox10 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox10);
  gtk_container_add (GTK_CONTAINER (notebook), vbox10);

  hbox19 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox19);
  gtk_box_pack_start (GTK_BOX (vbox10), hbox19, FALSE, FALSE, 0);

  image19 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image19);
  gtk_box_pack_start (GTK_BOX (hbox19), image19, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image19), 10, 0);

  label38 = gtk_label_new (_("<b><span size=\"large\">No application installed for RM/RAM\nReal Media files</span></b>"));
  gtk_widget_show (label38);
  gtk_box_pack_start (GTK_BOX (hbox19), label38, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label38), TRUE);

  label39 = gtk_label_new (_("You are trying to open a rm/ram file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label39);
  gtk_box_pack_start (GTK_BOX (vbox10), label39, FALSE, FALSE, 10);

  hbuttonbox10 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox10);
  gtk_box_pack_end (GTK_BOX (vbox10), hbuttonbox10, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox10), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox10), 10);

  page9_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page9_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox10), page9_cancel_button);
  GTK_WIDGET_SET_FLAGS (page9_cancel_button, GTK_CAN_DEFAULT);

  page9_install_button = gtk_button_new ();
  gtk_widget_show (page9_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox10), page9_install_button);
  GTK_WIDGET_SET_FLAGS (page9_install_button, GTK_CAN_DEFAULT);

  alignment10 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment10);
  gtk_container_add (GTK_CONTAINER (page9_install_button), alignment10);

  hbox20 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox20);
  gtk_container_add (GTK_CONTAINER (alignment10), hbox20);

  image20 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image20);
  gtk_box_pack_start (GTK_BOX (hbox20), image20, FALSE, FALSE, 0);

  label40 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label40);
  gtk_box_pack_start (GTK_BOX (hbox20), label40, FALSE, FALSE, 0);

  label28 = gtk_label_new (_("label28"));
  gtk_widget_show (label28);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 9), label28);

  vbox11 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox11);
  gtk_container_add (GTK_CONTAINER (notebook), vbox11);

  hbox21 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox21);
  gtk_box_pack_start (GTK_BOX (vbox11), hbox21, FALSE, FALSE, 0);

  image21 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image21);
  gtk_box_pack_start (GTK_BOX (hbox21), image21, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image21), 10, 0);

  label43 = gtk_label_new (_("<b><span size=\"large\">No application installed for MP3\nMpeg Layer 3 Audio files</span></b>"));
  gtk_widget_show (label43);
  gtk_box_pack_start (GTK_BOX (hbox21), label43, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label43), TRUE);

  label44 = gtk_label_new (_("You are trying to open a mp3 file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label44);
  gtk_box_pack_start (GTK_BOX (vbox11), label44, FALSE, FALSE, 10);

  hbuttonbox11 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox11);
  gtk_box_pack_end (GTK_BOX (vbox11), hbuttonbox11, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox11), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox11), 10);

  page10_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page10_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox11), page10_cancel_button);
  GTK_WIDGET_SET_FLAGS (page10_cancel_button, GTK_CAN_DEFAULT);

  page10_install_button = gtk_button_new ();
  gtk_widget_show (page10_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox11), page10_install_button);
  GTK_WIDGET_SET_FLAGS (page10_install_button, GTK_CAN_DEFAULT);

  alignment11 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment11);
  gtk_container_add (GTK_CONTAINER (page10_install_button), alignment11);

  hbox22 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox22);
  gtk_container_add (GTK_CONTAINER (alignment11), hbox22);

  image22 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image22);
  gtk_box_pack_start (GTK_BOX (hbox22), image22, FALSE, FALSE, 0);

  label45 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label45);
  gtk_box_pack_start (GTK_BOX (hbox22), label45, FALSE, FALSE, 0);

  label41 = gtk_label_new (_("label41"));
  gtk_widget_show (label41);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 10), label41);

  vbox12 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox12);
  gtk_container_add (GTK_CONTAINER (notebook), vbox12);

  hbox23 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox23);
  gtk_box_pack_start (GTK_BOX (vbox12), hbox23, FALSE, FALSE, 0);

  image23 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image23);
  gtk_box_pack_start (GTK_BOX (hbox23), image23, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image23), 10, 0);

  label46 = gtk_label_new (_("<b><span size=\"large\">No application installed for CBR\nComics files</span></b>"));
  gtk_widget_show (label46);
  gtk_box_pack_start (GTK_BOX (hbox23), label46, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label46), TRUE);

  label47 = gtk_label_new (_("You are trying to open a cbr file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label47);
  gtk_box_pack_start (GTK_BOX (vbox12), label47, FALSE, FALSE, 10);

  hbuttonbox12 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox12);
  gtk_box_pack_end (GTK_BOX (vbox12), hbuttonbox12, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox12), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox12), 10);

  page11_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page11_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox12), page11_cancel_button);
  GTK_WIDGET_SET_FLAGS (page11_cancel_button, GTK_CAN_DEFAULT);

  page11_install_button = gtk_button_new ();
  gtk_widget_show (page11_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox12), page11_install_button);
  GTK_WIDGET_SET_FLAGS (page11_install_button, GTK_CAN_DEFAULT);

  alignment12 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment12);
  gtk_container_add (GTK_CONTAINER (page11_install_button), alignment12);

  hbox24 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox24);
  gtk_container_add (GTK_CONTAINER (alignment12), hbox24);

  image24 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image24);
  gtk_box_pack_start (GTK_BOX (hbox24), image24, FALSE, FALSE, 0);

  label48 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label48);
  gtk_box_pack_start (GTK_BOX (hbox24), label48, FALSE, FALSE, 0);

  label42 = gtk_label_new (_("label42"));
  gtk_widget_show (label42);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 11), label42);

  vbox13 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox13);
  gtk_container_add (GTK_CONTAINER (notebook), vbox13);

  hbox25 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox25);
  gtk_box_pack_start (GTK_BOX (vbox13), hbox25, FALSE, FALSE, 0);

  image25 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image25);
  gtk_box_pack_start (GTK_BOX (hbox25), image25, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image25), 10, 0);

  label50 = gtk_label_new (_("<b><span size=\"large\">No application installed for CBZ\nComics files</span></b>"));
  gtk_widget_show (label50);
  gtk_box_pack_start (GTK_BOX (hbox25), label50, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label50), TRUE);

  label51 = gtk_label_new (_("You are trying to open a cbz file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label51);
  gtk_box_pack_start (GTK_BOX (vbox13), label51, FALSE, FALSE, 10);

  hbuttonbox13 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox13);
  gtk_box_pack_end (GTK_BOX (vbox13), hbuttonbox13, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox13), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox13), 10);

  page12_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page12_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox13), page12_cancel_button);
  GTK_WIDGET_SET_FLAGS (page12_cancel_button, GTK_CAN_DEFAULT);

  page12_install_button = gtk_button_new ();
  gtk_widget_show (page12_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox13), page12_install_button);
  GTK_WIDGET_SET_FLAGS (page12_install_button, GTK_CAN_DEFAULT);

  alignment13 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment13);
  gtk_container_add (GTK_CONTAINER (page12_install_button), alignment13);

  hbox26 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox26);
  gtk_container_add (GTK_CONTAINER (alignment13), hbox26);

  image26 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image26);
  gtk_box_pack_start (GTK_BOX (hbox26), image26, FALSE, FALSE, 0);

  label52 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label52);
  gtk_box_pack_start (GTK_BOX (hbox26), label52, FALSE, FALSE, 0);

  label49 = gtk_label_new (_("label49"));
  gtk_widget_show (label49);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 12), label49);

  vbox14 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox14);
  gtk_container_add (GTK_CONTAINER (notebook), vbox14);

  hbox27 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox27);
  gtk_box_pack_start (GTK_BOX (vbox14), hbox27, FALSE, FALSE, 0);

  image27 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image27);
  gtk_box_pack_start (GTK_BOX (hbox27), image27, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image27), 10, 0);

  label54 = gtk_label_new (_("<b><span size=\"large\">No application installed for CHM\nCompiled Help files</span></b>"));
  gtk_widget_show (label54);
  gtk_box_pack_start (GTK_BOX (hbox27), label54, FALSE, FALSE, 10);
  gtk_label_set_use_markup (GTK_LABEL (label54), TRUE);

  label55 = gtk_label_new (_("You are trying to open a chm file, however, there are no installed \nviewer for it in your computer.\n\nWould you like to enable the universe/multiverse repository\nand install the viewer?"));
  gtk_widget_show (label55);
  gtk_box_pack_start (GTK_BOX (vbox14), label55, FALSE, FALSE, 10);

  hbuttonbox14 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox14);
  gtk_box_pack_end (GTK_BOX (vbox14), hbuttonbox14, FALSE, FALSE, 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox14), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox14), 10);

  page13_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page13_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox14), page13_cancel_button);
  GTK_WIDGET_SET_FLAGS (page13_cancel_button, GTK_CAN_DEFAULT);

  page13_install_button = gtk_button_new ();
  gtk_widget_show (page13_install_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox14), page13_install_button);
  GTK_WIDGET_SET_FLAGS (page13_install_button, GTK_CAN_DEFAULT);

  alignment14 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment14);
  gtk_container_add (GTK_CONTAINER (page13_install_button), alignment14);

  hbox28 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox28);
  gtk_container_add (GTK_CONTAINER (alignment14), hbox28);

  image28 = gtk_image_new_from_icon_name ("stock_save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image28);
  gtk_box_pack_start (GTK_BOX (hbox28), image28, FALSE, FALSE, 0);

  label56 = gtk_label_new_with_mnemonic (_("_Install"));
  gtk_widget_show (label56);
  gtk_box_pack_start (GTK_BOX (hbox28), label56, FALSE, FALSE, 0);

  label53 = gtk_label_new (_("label53"));
  gtk_widget_show (label53);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 13), label53);

  g_signal_connect ((gpointer) window, "destroy",
                    G_CALLBACK (on_window_destroy),
                    NULL);
  g_signal_connect ((gpointer) page0_cancel_button, "clicked",
                    G_CALLBACK (on_page0_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page0_install_button, "clicked",
                    G_CALLBACK (on_page0_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page1_cancel_button, "clicked",
                    G_CALLBACK (on_page1_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page1_install_button, "clicked",
                    G_CALLBACK (on_page1_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page2_cancel_button, "clicked",
                    G_CALLBACK (on_page2_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page2_install_button, "clicked",
                    G_CALLBACK (on_page2_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page3_cancel_button, "clicked",
                    G_CALLBACK (on_page3_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page3_install_button, "clicked",
                    G_CALLBACK (on_page3_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page4_cancel_button, "clicked",
                    G_CALLBACK (on_page4_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page4_install_button, "clicked",
                    G_CALLBACK (on_page4_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page5_cancel_button, "clicked",
                    G_CALLBACK (on_page5_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page5_install_button, "clicked",
                    G_CALLBACK (on_page5_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page6_cancel_button, "clicked",
                    G_CALLBACK (on_page6_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page6_install_button, "clicked",
                    G_CALLBACK (on_page6_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page7_cancel_button, "clicked",
                    G_CALLBACK (on_page7_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page7_install_button, "clicked",
                    G_CALLBACK (on_page7_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page8_cancel_button, "clicked",
                    G_CALLBACK (on_page8_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page8_install_button, "clicked",
                    G_CALLBACK (on_page8_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page9_cancel_button, "clicked",
                    G_CALLBACK (on_page9_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page9_install_button, "clicked",
                    G_CALLBACK (on_page9_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page10_cancel_button, "clicked",
                    G_CALLBACK (on_page10_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page10_install_button, "clicked",
                    G_CALLBACK (on_page10_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page11_cancel_button, "clicked",
                    G_CALLBACK (on_page11_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page11_install_button, "clicked",
                    G_CALLBACK (on_page11_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page12_cancel_button, "clicked",
                    G_CALLBACK (on_page12_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page12_install_button, "clicked",
                    G_CALLBACK (on_page12_install_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page13_cancel_button, "clicked",
                    G_CALLBACK (on_page13_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page13_install_button, "clicked",
                    G_CALLBACK (on_page13_install_button_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window, window, "window");
  GLADE_HOOKUP_OBJECT (window, notebook, "notebook");
  GLADE_HOOKUP_OBJECT (window, vbox1, "vbox1");
  GLADE_HOOKUP_OBJECT (window, hbox1, "hbox1");
  GLADE_HOOKUP_OBJECT (window, image1, "image1");
  GLADE_HOOKUP_OBJECT (window, label4, "label4");
  GLADE_HOOKUP_OBJECT (window, label5, "label5");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox1, "hbuttonbox1");
  GLADE_HOOKUP_OBJECT (window, page0_cancel_button, "page0_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page0_install_button, "page0_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment1, "alignment1");
  GLADE_HOOKUP_OBJECT (window, hbox2, "hbox2");
  GLADE_HOOKUP_OBJECT (window, image2, "image2");
  GLADE_HOOKUP_OBJECT (window, label6, "label6");
  GLADE_HOOKUP_OBJECT (window, label1, "label1");
  GLADE_HOOKUP_OBJECT (window, vbox2, "vbox2");
  GLADE_HOOKUP_OBJECT (window, hbox3, "hbox3");
  GLADE_HOOKUP_OBJECT (window, image3, "image3");
  GLADE_HOOKUP_OBJECT (window, label7, "label7");
  GLADE_HOOKUP_OBJECT (window, label8, "label8");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox2, "hbuttonbox2");
  GLADE_HOOKUP_OBJECT (window, page1_cancel_button, "page1_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page1_install_button, "page1_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment2, "alignment2");
  GLADE_HOOKUP_OBJECT (window, hbox4, "hbox4");
  GLADE_HOOKUP_OBJECT (window, image4, "image4");
  GLADE_HOOKUP_OBJECT (window, label9, "label9");
  GLADE_HOOKUP_OBJECT (window, label2, "label2");
  GLADE_HOOKUP_OBJECT (window, vbox3, "vbox3");
  GLADE_HOOKUP_OBJECT (window, hbox5, "hbox5");
  GLADE_HOOKUP_OBJECT (window, image5, "image5");
  GLADE_HOOKUP_OBJECT (window, label10, "label10");
  GLADE_HOOKUP_OBJECT (window, label11, "label11");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox3, "hbuttonbox3");
  GLADE_HOOKUP_OBJECT (window, page2_cancel_button, "page2_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page2_install_button, "page2_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment3, "alignment3");
  GLADE_HOOKUP_OBJECT (window, hbox6, "hbox6");
  GLADE_HOOKUP_OBJECT (window, image6, "image6");
  GLADE_HOOKUP_OBJECT (window, label12, "label12");
  GLADE_HOOKUP_OBJECT (window, label3, "label3");
  GLADE_HOOKUP_OBJECT (window, vbox4, "vbox4");
  GLADE_HOOKUP_OBJECT (window, hbox7, "hbox7");
  GLADE_HOOKUP_OBJECT (window, image7, "image7");
  GLADE_HOOKUP_OBJECT (window, label16, "label16");
  GLADE_HOOKUP_OBJECT (window, label17, "label17");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox4, "hbuttonbox4");
  GLADE_HOOKUP_OBJECT (window, page3_cancel_button, "page3_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page3_install_button, "page3_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment4, "alignment4");
  GLADE_HOOKUP_OBJECT (window, hbox8, "hbox8");
  GLADE_HOOKUP_OBJECT (window, image8, "image8");
  GLADE_HOOKUP_OBJECT (window, label18, "label18");
  GLADE_HOOKUP_OBJECT (window, label13, "label13");
  GLADE_HOOKUP_OBJECT (window, vbox5, "vbox5");
  GLADE_HOOKUP_OBJECT (window, hbox9, "hbox9");
  GLADE_HOOKUP_OBJECT (window, image9, "image9");
  GLADE_HOOKUP_OBJECT (window, label19, "label19");
  GLADE_HOOKUP_OBJECT (window, label20, "label20");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox5, "hbuttonbox5");
  GLADE_HOOKUP_OBJECT (window, page4_cancel_button, "page4_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page4_install_button, "page4_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment5, "alignment5");
  GLADE_HOOKUP_OBJECT (window, hbox10, "hbox10");
  GLADE_HOOKUP_OBJECT (window, image10, "image10");
  GLADE_HOOKUP_OBJECT (window, label21, "label21");
  GLADE_HOOKUP_OBJECT (window, label14, "label14");
  GLADE_HOOKUP_OBJECT (window, vbox6, "vbox6");
  GLADE_HOOKUP_OBJECT (window, hbox11, "hbox11");
  GLADE_HOOKUP_OBJECT (window, image11, "image11");
  GLADE_HOOKUP_OBJECT (window, label22, "label22");
  GLADE_HOOKUP_OBJECT (window, label23, "label23");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox6, "hbuttonbox6");
  GLADE_HOOKUP_OBJECT (window, page5_cancel_button, "page5_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page5_install_button, "page5_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment6, "alignment6");
  GLADE_HOOKUP_OBJECT (window, hbox12, "hbox12");
  GLADE_HOOKUP_OBJECT (window, image12, "image12");
  GLADE_HOOKUP_OBJECT (window, label24, "label24");
  GLADE_HOOKUP_OBJECT (window, label15, "label15");
  GLADE_HOOKUP_OBJECT (window, vbox7, "vbox7");
  GLADE_HOOKUP_OBJECT (window, hbox13, "hbox13");
  GLADE_HOOKUP_OBJECT (window, image13, "image13");
  GLADE_HOOKUP_OBJECT (window, label29, "label29");
  GLADE_HOOKUP_OBJECT (window, label30, "label30");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox7, "hbuttonbox7");
  GLADE_HOOKUP_OBJECT (window, page6_cancel_button, "page6_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page6_install_button, "page6_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment7, "alignment7");
  GLADE_HOOKUP_OBJECT (window, hbox14, "hbox14");
  GLADE_HOOKUP_OBJECT (window, image14, "image14");
  GLADE_HOOKUP_OBJECT (window, label31, "label31");
  GLADE_HOOKUP_OBJECT (window, label25, "label25");
  GLADE_HOOKUP_OBJECT (window, vbox8, "vbox8");
  GLADE_HOOKUP_OBJECT (window, hbox15, "hbox15");
  GLADE_HOOKUP_OBJECT (window, image15, "image15");
  GLADE_HOOKUP_OBJECT (window, label32, "label32");
  GLADE_HOOKUP_OBJECT (window, label33, "label33");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox8, "hbuttonbox8");
  GLADE_HOOKUP_OBJECT (window, page7_cancel_button, "page7_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page7_install_button, "page7_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment8, "alignment8");
  GLADE_HOOKUP_OBJECT (window, hbox16, "hbox16");
  GLADE_HOOKUP_OBJECT (window, image16, "image16");
  GLADE_HOOKUP_OBJECT (window, label34, "label34");
  GLADE_HOOKUP_OBJECT (window, label26, "label26");
  GLADE_HOOKUP_OBJECT (window, vbox9, "vbox9");
  GLADE_HOOKUP_OBJECT (window, hbox17, "hbox17");
  GLADE_HOOKUP_OBJECT (window, image17, "image17");
  GLADE_HOOKUP_OBJECT (window, label35, "label35");
  GLADE_HOOKUP_OBJECT (window, label36, "label36");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox9, "hbuttonbox9");
  GLADE_HOOKUP_OBJECT (window, page8_cancel_button, "page8_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page8_install_button, "page8_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment9, "alignment9");
  GLADE_HOOKUP_OBJECT (window, hbox18, "hbox18");
  GLADE_HOOKUP_OBJECT (window, image18, "image18");
  GLADE_HOOKUP_OBJECT (window, label37, "label37");
  GLADE_HOOKUP_OBJECT (window, label27, "label27");
  GLADE_HOOKUP_OBJECT (window, vbox10, "vbox10");
  GLADE_HOOKUP_OBJECT (window, hbox19, "hbox19");
  GLADE_HOOKUP_OBJECT (window, image19, "image19");
  GLADE_HOOKUP_OBJECT (window, label38, "label38");
  GLADE_HOOKUP_OBJECT (window, label39, "label39");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox10, "hbuttonbox10");
  GLADE_HOOKUP_OBJECT (window, page9_cancel_button, "page9_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page9_install_button, "page9_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment10, "alignment10");
  GLADE_HOOKUP_OBJECT (window, hbox20, "hbox20");
  GLADE_HOOKUP_OBJECT (window, image20, "image20");
  GLADE_HOOKUP_OBJECT (window, label40, "label40");
  GLADE_HOOKUP_OBJECT (window, label28, "label28");
  GLADE_HOOKUP_OBJECT (window, vbox11, "vbox11");
  GLADE_HOOKUP_OBJECT (window, hbox21, "hbox21");
  GLADE_HOOKUP_OBJECT (window, image21, "image21");
  GLADE_HOOKUP_OBJECT (window, label43, "label43");
  GLADE_HOOKUP_OBJECT (window, label44, "label44");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox11, "hbuttonbox11");
  GLADE_HOOKUP_OBJECT (window, page10_cancel_button, "page10_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page10_install_button, "page10_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment11, "alignment11");
  GLADE_HOOKUP_OBJECT (window, hbox22, "hbox22");
  GLADE_HOOKUP_OBJECT (window, image22, "image22");
  GLADE_HOOKUP_OBJECT (window, label45, "label45");
  GLADE_HOOKUP_OBJECT (window, label41, "label41");
  GLADE_HOOKUP_OBJECT (window, vbox12, "vbox12");
  GLADE_HOOKUP_OBJECT (window, hbox23, "hbox23");
  GLADE_HOOKUP_OBJECT (window, image23, "image23");
  GLADE_HOOKUP_OBJECT (window, label46, "label46");
  GLADE_HOOKUP_OBJECT (window, label47, "label47");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox12, "hbuttonbox12");
  GLADE_HOOKUP_OBJECT (window, page11_cancel_button, "page11_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page11_install_button, "page11_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment12, "alignment12");
  GLADE_HOOKUP_OBJECT (window, hbox24, "hbox24");
  GLADE_HOOKUP_OBJECT (window, image24, "image24");
  GLADE_HOOKUP_OBJECT (window, label48, "label48");
  GLADE_HOOKUP_OBJECT (window, label42, "label42");
  GLADE_HOOKUP_OBJECT (window, vbox13, "vbox13");
  GLADE_HOOKUP_OBJECT (window, hbox25, "hbox25");
  GLADE_HOOKUP_OBJECT (window, image25, "image25");
  GLADE_HOOKUP_OBJECT (window, label50, "label50");
  GLADE_HOOKUP_OBJECT (window, label51, "label51");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox13, "hbuttonbox13");
  GLADE_HOOKUP_OBJECT (window, page12_cancel_button, "page12_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page12_install_button, "page12_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment13, "alignment13");
  GLADE_HOOKUP_OBJECT (window, hbox26, "hbox26");
  GLADE_HOOKUP_OBJECT (window, image26, "image26");
  GLADE_HOOKUP_OBJECT (window, label52, "label52");
  GLADE_HOOKUP_OBJECT (window, label49, "label49");
  GLADE_HOOKUP_OBJECT (window, vbox14, "vbox14");
  GLADE_HOOKUP_OBJECT (window, hbox27, "hbox27");
  GLADE_HOOKUP_OBJECT (window, image27, "image27");
  GLADE_HOOKUP_OBJECT (window, label54, "label54");
  GLADE_HOOKUP_OBJECT (window, label55, "label55");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox14, "hbuttonbox14");
  GLADE_HOOKUP_OBJECT (window, page13_cancel_button, "page13_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page13_install_button, "page13_install_button");
  GLADE_HOOKUP_OBJECT (window, alignment14, "alignment14");
  GLADE_HOOKUP_OBJECT (window, hbox28, "hbox28");
  GLADE_HOOKUP_OBJECT (window, image28, "image28");
  GLADE_HOOKUP_OBJECT (window, label56, "label56");
  GLADE_HOOKUP_OBJECT (window, label53, "label53");

  return window;
}

