#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

extern  GtkWidget *window;
extern  GtkWidget *notebook;

void
on_window_destroy                      (GtkObject       *object,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page0_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page0_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("zip\n");
gtk_main_quit();
}


void
on_page1_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page1_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("rar\n");
gtk_main_quit();
}


void
on_page2_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page2_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("wma\n");
gtk_main_quit();
}


void
on_page3_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page3_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("arj\n");
gtk_main_quit();
}


void
on_page4_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page4_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("m4a\n");
gtk_main_quit();
}


void
on_page5_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page5_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("ace\n");
gtk_main_quit();
}


void
on_page6_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page6_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("mov\n");
gtk_main_quit();
}


void
on_page7_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page7_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("mpg\n");
gtk_main_quit();
}


void
on_page8_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page8_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("aac\n");
gtk_main_quit();
}


void
on_page9_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page9_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("ram\n");
gtk_main_quit();
}


void
on_page10_cancel_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page10_install_button_clicked       (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("mp3\n");
gtk_main_quit();
}


void
on_page11_cancel_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page11_install_button_clicked       (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("cbr\n");
gtk_main_quit();
}


void
on_page12_cancel_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page12_install_button_clicked       (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("cbz\n");
gtk_main_quit();
}


void
on_page13_cancel_button_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("Exit_Signal\n");
gtk_main_quit();
}


void
on_page13_install_button_clicked       (GtkButton       *button,
                                        gpointer         user_data)
{
g_print("chm\n");
gtk_main_quit();
}

